@@ -1,4 +1,4 @@
-# Copyright 2018-2024 Michael Samoglyadov
+# Copyright 2018-2025 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '1.7.0'
+__version__ = '1.7.1'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -154,13 +154,15 @@ class Differ:
         if a is b:
             return True, {'U': a} if self.op_u else {}
 
+        differ = self.default_differ
+
         if a.__class__ is b.__class__:
             try:
-                return self._differs[a.__class__](self, a, b)
+                differ = self._differs[a.__class__]
             except KeyError:
                 pass
 
-        return self.default_differ(self, a, b)
+        return differ(self, a, b)
 
     def set_handler(self, handler):
         """Set handler.
